# VoxelFuse-Primitives
Classes for generating primitives using the [VoxelFuse](https://github.com/cdbrauer/VoxelFuse) library.

![Example 1](../master/images/main.png?raw=true)

## Installation

The voxelfuse_primitives library can be installed using pip.

    pip3 install voxelfuse-primitives
    
The classes needed by your script can then be imported in Python.  For example:

    from voxelfuse_primitives.solid import Solid
    from voxelfuse_primitives.linkage import Linkage
